==> xmpp-extensions-0.5.1-sources.jar: rocks/xmpp/extensions/pubsub/model/Subscription.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2015 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.pubsub.model;

import rocks.xmpp.core.Jid;

import java.util.Date;

/**
 * Represents the {@code <subscription/>} element, which is used in both 'pubsub' and 'pubsub#owner' namespace.
 *
 * @author Christian Schudt
 */
public interface Subscription {

    Jid getJid();

    /**
     * Gets the node.
     *
     * @return The node.
     */
    String getNode();

    String getSubId();

    /**
     * Gets the subscription state to a node.
     *
     * @return The subscription state.
     */
    SubscriptionState getSubscriptionState();

    Date getExpiry();

    boolean isConfigurationRequired();

    boolean isConfigurationSupported();
}

==> xmpp-extensions-0.6.1-sources.jar: rocks/xmpp/extensions/pubsub/model/Subscription.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2015 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.pubsub.model;

import rocks.xmpp.addr.Jid;

import java.time.Instant;

/**
 * Represents the {@code <subscription/>} element, which is used in both 'pubsub' and 'pubsub#owner' namespace.
 *
 * @author Christian Schudt
 */
public interface Subscription {

    Jid getJid();

    /**
     * Gets the node.
     *
     * @return The node.
     */
    String getNode();

    String getSubId();

    /**
     * Gets the subscription state to a node.
     *
     * @return The subscription state.
     */
    SubscriptionState getSubscriptionState();

    Instant getExpiry();

    boolean isConfigurationRequired();

    boolean isConfigurationSupported();
}
